@@ -3,10 +3,16 @@ function(ModelC, ModelA)
 {
   sseC = sum(residuals(ModelC)^2)
   sseA = sum(residuals(ModelA)^2)
-
+  
   pC = length(coef(ModelC))
   pA = length(coef(ModelA))
-  if (!(pA > pC))  stop('Invalid model comparison:  modelA does not have more parameters than modelC')
+  if (!(pA > pC))  stop('Invalid model comparison:  ModelA does not have more parameters than ModelC')
+  
+  #Added the next three lines to check whether the terms in model C are a subset of the terms in model A
+  termsC <- attr(terms(ModelC), "term.labels")
+  termsA <- attr(terms(ModelA), "term.labels")
+  
+  if (!all(termsC %in% termsA))  stop('Invalid model comparison:  ModelC is not a subset of ModelA')
 
   nC = ModelC$df.residual + pC
   nA = ModelA$df.residual + pA
@@ -30,4 +36,4 @@ function(ModelC, ModelA)
   
   Results = list(sseC=sseC, sseA=sseA, pC=pC, pA=pA, nDF=nDF, dDF=dDF, Fstat=FStat, p=p,  PRE=PRE, DeltaR2=DeltaR2)
   invisible(Results)  #return but dont print list
-}
\ No newline at end of file
+}
